@@ -35,31 +35,35 @@ from tests.base import mock
 from tests.cmd.test_cmd import CmdTestsBase
 
 
-@mock.patch('jenkins_jobs.builder.JenkinsManager.get_plugins_info',
-            mock.MagicMock)
+@mock.patch("jenkins_jobs.builder.JenkinsManager.get_plugins_info", mock.MagicMock)
 class TestTests(CmdTestsBase):
-
     def test_non_existing_job(self):
         """
         Run test mode and pass a non-existing job name
         (probably better to fail here)
         """
-        args = ['--conf', self.default_config_file, 'test',
-                os.path.join(self.fixtures_path,
-                             'cmd-001.yaml'),
-                'invalid']
+        args = [
+            "--conf",
+            self.default_config_file,
+            "test",
+            os.path.join(self.fixtures_path, "cmd-001.yaml"),
+            "invalid",
+        ]
         self.execute_jenkins_jobs_with_args(args)
 
     def test_valid_job(self):
         """
         Run test mode and pass a valid job name
         """
-        args = ['--conf', self.default_config_file, 'test',
-                os.path.join(self.fixtures_path,
-                             'cmd-001.yaml'),
-                'foo-job']
+        args = [
+            "--conf",
+            self.default_config_file,
+            "test",
+            os.path.join(self.fixtures_path, "cmd-001.yaml"),
+            "foo-job",
+        ]
         console_out = io.BytesIO()
-        with mock.patch('sys.stdout', console_out):
+        with mock.patch("sys.stdout", console_out):
             self.execute_jenkins_jobs_with_args(args)
 
     def test_console_output(self):
@@ -68,13 +72,18 @@ class TestTests(CmdTestsBase):
         """
 
         console_out = io.BytesIO()
-        with mock.patch('sys.stdout', console_out):
-            args = ['--conf', self.default_config_file, 'test',
-                    os.path.join(self.fixtures_path, 'cmd-001.yaml')]
+        with mock.patch("sys.stdout", console_out):
+            args = [
+                "--conf",
+                self.default_config_file,
+                "test",
+                os.path.join(self.fixtures_path, "cmd-001.yaml"),
+            ]
             self.execute_jenkins_jobs_with_args(args)
-        xml_content = io.open(os.path.join(self.fixtures_path, 'cmd-001.xml'),
-                              'r', encoding='utf-8').read()
-        self.assertEqual(console_out.getvalue().decode('utf-8'), xml_content)
+        xml_content = io.open(
+            os.path.join(self.fixtures_path, "cmd-001.xml"), "r", encoding="utf-8"
+        ).read()
+        self.assertEqual(console_out.getvalue().decode("utf-8"), xml_content)
 
     def test_output_dir(self):
         """
@@ -83,11 +92,11 @@ class TestTests(CmdTestsBase):
         """
         tmpdir = tempfile.mkdtemp()
         self.addCleanup(shutil.rmtree, tmpdir)
-        args = ['test', os.path.join(self.fixtures_path, 'cmd-001.yaml'),
-                '-o', tmpdir]
+        args = ["test", os.path.join(self.fixtures_path, "cmd-001.yaml"), "-o", tmpdir]
         self.execute_jenkins_jobs_with_args(args)
-        self.expectThat(os.path.join(tmpdir, 'foo-job'),
-                        testtools.matchers.FileExists())
+        self.expectThat(
+            os.path.join(tmpdir, "foo-job"), testtools.matchers.FileExists()
+        )
 
     def test_output_dir_config_xml(self):
         """
@@ -96,11 +105,18 @@ class TestTests(CmdTestsBase):
         """
         tmpdir = tempfile.mkdtemp()
         self.addCleanup(shutil.rmtree, tmpdir)
-        args = ['test', os.path.join(self.fixtures_path, 'cmd-001.yaml'),
-                '-o', tmpdir, '--config-xml']
+        args = [
+            "test",
+            os.path.join(self.fixtures_path, "cmd-001.yaml"),
+            "-o",
+            tmpdir,
+            "--config-xml",
+        ]
         self.execute_jenkins_jobs_with_args(args)
-        self.expectThat(os.path.join(tmpdir, 'foo-job', 'config.xml'),
-                        testtools.matchers.FileExists())
+        self.expectThat(
+            os.path.join(tmpdir, "foo-job", "config.xml"),
+            testtools.matchers.FileExists(),
+        )
 
     def test_stream_input_output_no_encoding_exceed_recursion(self):
         """
@@ -109,13 +125,12 @@ class TestTests(CmdTestsBase):
         """
         console_out = io.BytesIO()
 
-        input_file = os.path.join(self.fixtures_path,
-                                  'large-number-of-jobs-001.yaml')
-        with io.open(input_file, 'r') as f:
-            with mock.patch('sys.stdout', console_out):
+        input_file = os.path.join(self.fixtures_path, "large-number-of-jobs-001.yaml")
+        with io.open(input_file, "r") as f:
+            with mock.patch("sys.stdout", console_out):
                 console_out.encoding = None
-                with mock.patch('sys.stdin', f):
-                    args = ['test']
+                with mock.patch("sys.stdin", f):
+                    args = ["test"]
                     self.execute_jenkins_jobs_with_args(args)
 
     def test_stream_input_output_utf8_encoding(self):
@@ -125,16 +140,17 @@ class TestTests(CmdTestsBase):
         """
         console_out = io.BytesIO()
 
-        input_file = os.path.join(self.fixtures_path, 'cmd-001.yaml')
-        with io.open(input_file, 'r') as f:
-            with mock.patch('sys.stdout', console_out):
-                with mock.patch('sys.stdin', f):
-                    args = ['--conf', self.default_config_file, 'test']
+        input_file = os.path.join(self.fixtures_path, "cmd-001.yaml")
+        with io.open(input_file, "r") as f:
+            with mock.patch("sys.stdout", console_out):
+                with mock.patch("sys.stdin", f):
+                    args = ["--conf", self.default_config_file, "test"]
                     self.execute_jenkins_jobs_with_args(args)
 
-        xml_content = io.open(os.path.join(self.fixtures_path, 'cmd-001.xml'),
-                              'r', encoding='utf-8').read()
-        value = console_out.getvalue().decode('utf-8')
+        xml_content = io.open(
+            os.path.join(self.fixtures_path, "cmd-001.xml"), "r", encoding="utf-8"
+        ).read()
+        value = console_out.getvalue().decode("utf-8")
         self.assertEqual(value, xml_content)
 
     def test_stream_input_output_ascii_encoding(self):
@@ -143,18 +159,19 @@ class TestTests(CmdTestsBase):
         ascii encoding with unicode input
         """
         console_out = io.BytesIO()
-        console_out.encoding = 'ascii'
+        console_out.encoding = "ascii"
 
-        input_file = os.path.join(self.fixtures_path, 'cmd-001.yaml')
-        with io.open(input_file, 'r') as f:
-            with mock.patch('sys.stdout', console_out):
-                with mock.patch('sys.stdin', f):
-                    args = ['--conf', self.default_config_file, 'test']
+        input_file = os.path.join(self.fixtures_path, "cmd-001.yaml")
+        with io.open(input_file, "r") as f:
+            with mock.patch("sys.stdout", console_out):
+                with mock.patch("sys.stdin", f):
+                    args = ["--conf", self.default_config_file, "test"]
                     self.execute_jenkins_jobs_with_args(args)
 
-        xml_content = io.open(os.path.join(self.fixtures_path, 'cmd-001.xml'),
-                              'r', encoding='utf-8').read()
-        value = console_out.getvalue().decode('ascii')
+        xml_content = io.open(
+            os.path.join(self.fixtures_path, "cmd-001.xml"), "r", encoding="utf-8"
+        ).read()
+        value = console_out.getvalue().decode("ascii")
         self.assertEqual(value, xml_content)
 
     def test_stream_output_ascii_encoding_invalid_char(self):
@@ -164,65 +181,65 @@ class TestTests(CmdTestsBase):
         that cannot be converted.
         """
         console_out = io.BytesIO()
-        console_out.encoding = 'ascii'
+        console_out.encoding = "ascii"
 
-        input_file = os.path.join(self.fixtures_path, 'unicode001.yaml')
-        with io.open(input_file, 'r', encoding='utf-8') as f:
-            with mock.patch('sys.stdout', console_out):
-                with mock.patch('sys.stdin', f):
-                    args = ['--conf', self.default_config_file, 'test']
+        input_file = os.path.join(self.fixtures_path, "unicode001.yaml")
+        with io.open(input_file, "r", encoding="utf-8") as f:
+            with mock.patch("sys.stdout", console_out):
+                with mock.patch("sys.stdin", f):
+                    args = ["--conf", self.default_config_file, "test"]
                     jenkins_jobs = entry.JenkinsJobs(args)
                     e = self.assertRaises(UnicodeError, jenkins_jobs.execute)
         self.assertIn("'ascii' codec can't encode character", str(e))
 
-    @mock.patch(
-        'jenkins_jobs.cli.subcommand.update.XmlJobGenerator.generateXML')
-    @mock.patch('jenkins_jobs.cli.subcommand.update.ModuleRegistry')
+    @mock.patch("jenkins_jobs.cli.subcommand.update.XmlJobGenerator.generateXML")
+    @mock.patch("jenkins_jobs.cli.subcommand.update.ModuleRegistry")
     def test_plugins_info_stub_option(self, registry_mock, generateXML_mock):
         """
         Test handling of plugins_info stub option.
         """
-        plugins_info_stub_yaml_file = os.path.join(self.fixtures_path,
-                                                   'plugins-info.yaml')
-        args = ['--conf',
-                os.path.join(self.fixtures_path, 'cmd-001.conf'),
-                'test',
-                '-p',
-                plugins_info_stub_yaml_file,
-                os.path.join(self.fixtures_path, 'cmd-001.yaml')]
+        plugins_info_stub_yaml_file = os.path.join(
+            self.fixtures_path, "plugins-info.yaml"
+        )
+        args = [
+            "--conf",
+            os.path.join(self.fixtures_path, "cmd-001.conf"),
+            "test",
+            "-p",
+            plugins_info_stub_yaml_file,
+            os.path.join(self.fixtures_path, "cmd-001.yaml"),
+        ]
 
         self.execute_jenkins_jobs_with_args(args)
 
-        with io.open(plugins_info_stub_yaml_file,
-                     'r', encoding='utf-8') as yaml_file:
-            plugins_info_list = yaml.load(yaml_file)
+        with io.open(plugins_info_stub_yaml_file, "r", encoding="utf-8") as yaml_file:
+            plugins_info_list = yaml.safe_load(yaml_file)
 
-        registry_mock.assert_called_with(mock.ANY,
-                                         plugins_info_list)
+        registry_mock.assert_called_with(mock.ANY, plugins_info_list)
 
-    @mock.patch(
-        'jenkins_jobs.cli.subcommand.update.XmlJobGenerator.generateXML')
-    @mock.patch('jenkins_jobs.cli.subcommand.update.ModuleRegistry')
-    def test_bogus_plugins_info_stub_option(self, registry_mock,
-                                            generateXML_mock):
+    @mock.patch("jenkins_jobs.cli.subcommand.update.XmlJobGenerator.generateXML")
+    @mock.patch("jenkins_jobs.cli.subcommand.update.ModuleRegistry")
+    def test_bogus_plugins_info_stub_option(self, registry_mock, generateXML_mock):
         """
         Verify that a JenkinsJobException is raised if the plugins_info stub
         file does not yield a list as its top-level object.
         """
-        plugins_info_stub_yaml_file = os.path.join(self.fixtures_path,
-                                                   'bogus-plugins-info.yaml')
-        args = ['--conf',
-                os.path.join(self.fixtures_path, 'cmd-001.conf'),
-                'test',
-                '-p',
-                plugins_info_stub_yaml_file,
-                os.path.join(self.fixtures_path, 'cmd-001.yaml')]
+        plugins_info_stub_yaml_file = os.path.join(
+            self.fixtures_path, "bogus-plugins-info.yaml"
+        )
+        args = [
+            "--conf",
+            os.path.join(self.fixtures_path, "cmd-001.conf"),
+            "test",
+            "-p",
+            plugins_info_stub_yaml_file,
+            os.path.join(self.fixtures_path, "cmd-001.yaml"),
+        ]
 
         stderr = StringIO()
-        with mock.patch('sys.stderr', stderr):
+        with mock.patch("sys.stderr", stderr):
             self.assertRaises(SystemExit, entry.JenkinsJobs, args)
-        self.assertIn("must contain a Yaml list",
-                      stderr.getvalue())
+        self.assertIn("must contain a Yaml list", stderr.getvalue())
 
 
 class TestJenkinsGetPluginInfoError(CmdTestsBase):
@@ -231,9 +248,8 @@ class TestJenkinsGetPluginInfoError(CmdTestsBase):
     jenkins_jobs.builder.JenkinsManager.get_plugins_info
     """
 
-    @mock.patch('jenkins.Jenkins.get_plugins')
-    def test_console_output_jenkins_connection_failure_warning(
-            self, get_plugins_mock):
+    @mock.patch("jenkins.Jenkins.get_plugins")
+    def test_console_output_jenkins_connection_failure_warning(self, get_plugins_mock):
         """
         Run test mode and verify that failed Jenkins connection attempt
         exception does not bubble out of cmd.main. Ideally, we would also test
@@ -242,44 +258,51 @@ class TestJenkinsGetPluginInfoError(CmdTestsBase):
         suite.
         """
 
-        get_plugins_mock.side_effect = \
-            jenkins.JenkinsException("Connection refused")
-        with mock.patch('sys.stdout'):
+        get_plugins_mock.side_effect = jenkins.JenkinsException("Connection refused")
+        with mock.patch("sys.stdout"):
             try:
-                args = ['--conf', self.default_config_file, 'test',
-                        os.path.join(self.fixtures_path, 'cmd-001.yaml')]
+                args = [
+                    "--conf",
+                    self.default_config_file,
+                    "test",
+                    os.path.join(self.fixtures_path, "cmd-001.yaml"),
+                ]
                 self.execute_jenkins_jobs_with_args(args)
             except jenkins.JenkinsException:
                 self.fail("jenkins.JenkinsException propagated to main")
             except Exception:
                 pass  # only care about jenkins.JenkinsException for now
 
-    @mock.patch('jenkins.Jenkins.get_plugins')
-    def test_skip_plugin_retrieval_if_no_config_provided(
-            self, get_plugins_mock):
+    @mock.patch("jenkins.Jenkins.get_plugins")
+    def test_skip_plugin_retrieval_if_no_config_provided(self, get_plugins_mock):
         """
         Verify that retrieval of information from Jenkins instance about its
         plugins will be skipped when run if no config file provided.
         """
-        with mock.patch('sys.stdout', new_callable=io.BytesIO):
-            args = ['--conf', self.default_config_file, 'test',
-                    os.path.join(self.fixtures_path, 'cmd-001.yaml')]
+        with mock.patch("sys.stdout", new_callable=io.BytesIO):
+            args = [
+                "--conf",
+                self.default_config_file,
+                "test",
+                os.path.join(self.fixtures_path, "cmd-001.yaml"),
+            ]
             entry.JenkinsJobs(args)
         self.assertFalse(get_plugins_mock.called)
 
-    @mock.patch('jenkins.Jenkins.get_plugins_info')
+    @mock.patch("jenkins.Jenkins.get_plugins_info")
     def test_skip_plugin_retrieval_if_disabled(self, get_plugins_mock):
         """
         Verify that retrieval of information from Jenkins instance about its
         plugins will be skipped when run if a config file provided and disables
         querying through a config option.
         """
-        with mock.patch('sys.stdout', new_callable=io.BytesIO):
-            args = ['--conf',
-                    os.path.join(self.fixtures_path,
-                                 'disable-query-plugins.conf'),
-                    'test',
-                    os.path.join(self.fixtures_path, 'cmd-001.yaml')]
+        with mock.patch("sys.stdout", new_callable=io.BytesIO):
+            args = [
+                "--conf",
+                os.path.join(self.fixtures_path, "disable-query-plugins.conf"),
+                "test",
+                os.path.join(self.fixtures_path, "cmd-001.yaml"),
+            ]
             entry.JenkinsJobs(args)
         self.assertFalse(get_plugins_mock.called)
 
@@ -291,8 +314,8 @@ class MatchesDirMissingFilesMismatch(object):
 
     def describe(self):
         return "{0} and {1} contain different files".format(
-            self.left_directory,
-            self.right_directory)
+            self.left_directory, self.right_directory
+        )
 
     def get_details(self):
         return {}
@@ -308,11 +331,15 @@ class MatchesDirFileContentsMismatch(object):
         right_contents = open(self.right_file).readlines()
 
         return "{0} is not equal to {1}:\n{2}".format(
-            difflib.unified_diff(left_contents, right_contents,
-                                 fromfile=self.left_file,
-                                 tofile=self.right_file),
+            difflib.unified_diff(
+                left_contents,
+                right_contents,
+                fromfile=self.left_file,
+                tofile=self.right_file,
+            ),
             self.left_file,
-            self.right_file)
+            self.right_file,
+        )
 
     def get_details(self):
         return {}
@@ -337,8 +364,7 @@ class MatchesDir(object):
         other_files.sort()
 
         if self.__files != other_files:
-            return MatchesDirMissingFilesMismatch(self.__directory,
-                                                  other_directory)
+            return MatchesDirMissingFilesMismatch(self.__directory, other_directory)
 
         for i, file in enumerate(self.__files):
             my_file = os.path.join(self.__directory, file)
@@ -349,16 +375,15 @@ class MatchesDir(object):
         return None
 
 
-@mock.patch('jenkins_jobs.builder.JenkinsManager.get_plugins_info',
-            mock.MagicMock)
+@mock.patch("jenkins_jobs.builder.JenkinsManager.get_plugins_info", mock.MagicMock)
 class TestTestsMultiPath(CmdTestsBase):
-
     def setUp(self):
         super(TestTestsMultiPath, self).setUp()
 
-        path_list = [os.path.join(self.fixtures_path,
-                                  'multi-path/yamldirs/', p)
-                     for p in ['dir1', 'dir2']]
+        path_list = [
+            os.path.join(self.fixtures_path, "multi-path/yamldirs/", p)
+            for p in ["dir1", "dir2"]
+        ]
         self.multipath = os.pathsep.join(path_list)
         self.output_dir = tempfile.mkdtemp()
 
@@ -374,45 +399,74 @@ class TestTestsMultiPath(CmdTestsBase):
         """
         Run test mode and pass multiple paths.
         """
-        args = ['--conf', self.default_config_file, 'test',
-                '-o', self.output_dir, self.multipath]
+        args = [
+            "--conf",
+            self.default_config_file,
+            "test",
+            "-o",
+            self.output_dir,
+            self.multipath,
+        ]
 
         self.execute_jenkins_jobs_with_args(args)
-        self.check_dirs_match(os.path.join(self.fixtures_path,
-                                           'multi-path/output_simple'))
+        self.check_dirs_match(
+            os.path.join(self.fixtures_path, "multi-path/output_simple")
+        )
 
     def test_recursive_multi_path_command_line(self):
         """
         Run test mode and pass multiple paths with recursive path option.
         """
-        args = ['--conf', self.default_config_file, 'test',
-                '-o', self.output_dir, '-r', self.multipath]
+        args = [
+            "--conf",
+            self.default_config_file,
+            "test",
+            "-o",
+            self.output_dir,
+            "-r",
+            self.multipath,
+        ]
 
         self.execute_jenkins_jobs_with_args(args)
-        self.check_dirs_match(os.path.join(self.fixtures_path,
-                                           'multi-path/output_recursive'))
+        self.check_dirs_match(
+            os.path.join(self.fixtures_path, "multi-path/output_recursive")
+        )
 
     def test_recursive_multi_path_config_file(self):
         # test recursive set in configuration file
-        args = ['--conf', os.path.join(self.fixtures_path,
-                                       'multi-path/builder-recursive.ini'),
-                'test', '-o', self.output_dir, self.multipath]
+        args = [
+            "--conf",
+            os.path.join(self.fixtures_path, "multi-path/builder-recursive.ini"),
+            "test",
+            "-o",
+            self.output_dir,
+            self.multipath,
+        ]
         self.execute_jenkins_jobs_with_args(args)
-        self.check_dirs_match(os.path.join(self.fixtures_path,
-                                           'multi-path/output_recursive'))
+        self.check_dirs_match(
+            os.path.join(self.fixtures_path, "multi-path/output_recursive")
+        )
 
     def test_recursive_multi_path_with_excludes(self):
         """
         Run test mode and pass multiple paths with recursive path option.
         """
-        exclude_path = os.path.join(self.fixtures_path,
-                                    'multi-path/yamldirs/dir2/dir1')
-        args = ['--conf', self.default_config_file, 'test',
-                '-x', exclude_path,
-                '-o', self.output_dir,
-                '-r', self.multipath]
+        exclude_path = os.path.join(self.fixtures_path, "multi-path/yamldirs/dir2/dir1")
+        args = [
+            "--conf",
+            self.default_config_file,
+            "test",
+            "-x",
+            exclude_path,
+            "-o",
+            self.output_dir,
+            "-r",
+            self.multipath,
+        ]
 
         self.execute_jenkins_jobs_with_args(args)
         self.check_dirs_match(
-            os.path.join(self.fixtures_path,
-                         'multi-path/output_recursive_with_excludes'))
+            os.path.join(
+                self.fixtures_path, "multi-path/output_recursive_with_excludes"
+            )
+        )
