@@ -19,6 +19,6 @@ from tests import base
 
 
 class TestCaseModulePublishers(base.BaseScenariosTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'fixtures')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
     scenarios = base.get_scenarios(fixtures_path)
     klass = hipchat_notif.HipChat
