@@ -21,5 +21,5 @@ from tests import base
 
 
 class TestCaseModuleSCMMacro(base.SingleJobTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'fixtures')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
     scenarios = base.get_scenarios(fixtures_path)
