@@ -21,6 +21,6 @@ from tests import base
 
 
 class TestCaseModuleReporters(base.BaseScenariosTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'fixtures')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
     scenarios = base.get_scenarios(fixtures_path)
     klass = reporters.Reporters
