@@ -15,23 +15,37 @@
 import os
 from jenkins_jobs.modules import view_all
 from jenkins_jobs.modules import view_list
+from jenkins_jobs.modules import view_nested
 from jenkins_jobs.modules import view_pipeline
+from jenkins_jobs.modules import view_sectioned
 from tests import base
 
 
 class TestCaseModuleViewAll(base.BaseScenariosTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'fixtures')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
     scenarios = base.get_scenarios(fixtures_path)
     klass = view_all.All
 
 
 class TestCaseModuleViewList(base.BaseScenariosTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'fixtures')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
     scenarios = base.get_scenarios(fixtures_path)
     klass = view_list.List
 
 
+class TestCaseModuleViewNested(base.BaseScenariosTestCase):
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
+    scenarios = base.get_scenarios(fixtures_path)
+    klass = view_nested.Nested
+
+
 class TestCaseModuleViewPipeline(base.BaseScenariosTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'fixtures')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
     scenarios = base.get_scenarios(fixtures_path)
     klass = view_pipeline.Pipeline
+
+
+class TestCaseModuleViewSectioned(base.BaseScenariosTestCase):
+    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
+    scenarios = base.get_scenarios(fixtures_path)
+    klass = view_sectioned.Sectioned
