@@ -23,23 +23,23 @@ from tests import base
 
 
 class TestXmlJobGeneratorExceptions(base.BaseTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), 'exceptions')
+    fixtures_path = os.path.join(os.path.dirname(__file__), "exceptions")
 
     def test_invalid_project(self):
         self.conf_filename = None
         config = self._get_config()
 
         yp = parser.YamlParser(config)
-        yp.parse(os.path.join(self.fixtures_path,
-                              "invalid_project.yaml"))
+        yp.parse(os.path.join(self.fixtures_path, "invalid_project.yaml"))
 
         reg = registry.ModuleRegistry(config)
         job_data, _ = yp.expandYaml(reg)
 
         # Generate the XML tree
         xml_generator = xml_config.XmlJobGenerator(reg)
-        e = self.assertRaises(errors.JenkinsJobsException,
-                              xml_generator.generateXML, job_data)
+        e = self.assertRaises(
+            errors.JenkinsJobsException, xml_generator.generateXML, job_data
+        )
         self.assertIn("Unrecognized project-type:", str(e))
 
     def test_invalid_view(self):
@@ -54,8 +54,9 @@ class TestXmlJobGeneratorExceptions(base.BaseTestCase):
 
         # Generate the XML tree
         xml_generator = xml_config.XmlViewGenerator(reg)
-        e = self.assertRaises(errors.JenkinsJobsException,
-                              xml_generator.generateXML, view_data)
+        e = self.assertRaises(
+            errors.JenkinsJobsException, xml_generator.generateXML, view_data
+        )
         self.assertIn("Unrecognized view-type:", str(e))
 
     def test_incorrect_template_params(self):
@@ -63,8 +64,7 @@ class TestXmlJobGeneratorExceptions(base.BaseTestCase):
         config = self._get_config()
 
         yp = parser.YamlParser(config)
-        yp.parse(os.path.join(self.fixtures_path,
-                              "failure_formatting_component.yaml"))
+        yp.parse(os.path.join(self.fixtures_path, "failure_formatting_component.yaml"))
 
         reg = registry.ModuleRegistry(config)
         reg.set_parser_data(yp.data)
